Struct FulfillmentCtxt
pub struct FulfillmentCtxt<'db> {
obligations: ObligationStorage<'db>,
usable_in_snapshot: usize,
try_evaluate_obligations_scratch: Vec<(Obligation<'db, Predicate<'db>>, Option<GoalStalledOn<DbInterner<'db>>>)>,
}Expand description
A trait engine using the new trait solver.
This is mostly identical to how evaluate_all works inside of the
solver, except that the requirements are slightly different.
Unlike evaluate_all it is possible to add new obligations later on
and we also have to track diagnostics information by using Obligation
instead of Goal.
It is also likely that we want to use slightly different datastructures
here as this will have to deal with far more root goals than evaluate_all.
Fields
obligations: ObligationStorage<'db>usable_in_snapshot: usizetry_evaluate_obligations_scratch: Vec<(Obligation<'db, Predicate<'db>>, Option<GoalStalledOn<DbInterner<'db>>>)>Implementations
impl<'db> FulfillmentCtxt<'db>
impl<'db> FulfillmentCtxt<'db>
pub fn new(infcx: &InferCtxt<'db>) -> FulfillmentCtxt<'db>